%% N-point causal moving average

close all

%Only need to look at a single period because H(e^{jw}) is periodic with 
%period 2*pi
w=-pi:0.001:pi;
N=2:10:52; %Look at the response for these different lengths

%This part will create a matrix where each row is the frequency response 
%for a particular N value. The code H=[H; ...] creates a new H by
%concatenating a new H onto the bottom of the old one. The plot function
%will use each row as a separate line when we plot.
H=[];
for i=1:length(N)
    H=[H; 1/N(i).*(exp(-1j*w*(N(i)-1))).*(sin(w*N(i)/2)./sin(w/2))];
end


subplot(2,1,1)
plot(w,abs(H)) %Plot the magnitude of the frequency response
xlabel('\omega', 'FontSize',14)
title('|H(j\omega)|','FontSize',16)
set(gca, 'FontSize',12)
legend(num2str(N', 'N=%d'))
axis tight
grid on

subplot(2,1,2)
plot(w,unwrap(angle(H))) % Plot the angle (phase)
xlabel('\omega', 'FontSize',14)
title('angle(H(j\omega))','FontSize',16)
set(gca, 'FontSize',12)
legend(num2str(N', 'N=%d'))
axis tight
grid on